export const config = {
  social: {
    x: 'https://x.com/actoboticsnet',
    github: 'https://github.com/actobotics/ACTO',
  },
  links: {
    docs: 'https://docs.actobotics.net',
    repository: 'https://github.com/actobotics/ACTO',
    dashboard: 'https://api.actobotics.net/dashboard',
    pypi: 'https://pypi.org/project/actobotics/',
    api: 'https://api.actobotics.net',
  },
};
